@@ -24,7 +24,7 @@ from bcbio.pipeline import (archive, config_utils, disambiguate, region,
 from bcbio.provenance import profile, system
 from bcbio.variation import (ensemble, genotype, population, validate, joint,
                              peddy)
-from bcbio.chipseq import peaks
+from bcbio.chipseq import peaks, atac
 
 def run_main(workdir, config_file=None, fc_dir=None, run_info_yaml=None,
              parallel=None, workflow=None):
@@ -152,7 +152,8 @@ def variant2pipeline(config, run_info_yaml, parallel, dirs, samples):
             samples = region.parallel_prep_region(samples, run_parallel)
         with profile.report("variant calling", dirs):
             samples = genotype.parallel_variantcall_region(samples, run_parallel)
-
+        with profile.report("joint squaring off/backfilling", dirs):
+            samples = joint.square_off(samples, run_parallel)
     ## Finalize variants, BAMs and population databases (per-sample multicore cluster)
     with prun.start(_wres(parallel, ["gatk", "gatk-vqsr", "snpeff", "bcbio_variation",
                                      "gemini", "samtools", "fastqc", "sambamba",
@@ -160,8 +161,6 @@ def variant2pipeline(config, run_info_yaml, parallel, dirs, samples):
                                      "svcaller", "kraken", "preseq"]),
                     samples, config, dirs, "multicore2",
                     multiplier=structural.parallel_multiplier(samples)) as run_parallel:
-        with profile.report("joint squaring off/backfilling", dirs):
-            samples = joint.square_off(samples, run_parallel)
         with profile.report("variant post-processing", dirs):
             samples = run_parallel("postprocess_variants", samples)
             samples = run_parallel("split_variants_by_sample", samples)
@@ -186,6 +185,9 @@ def variant2pipeline(config, run_info_yaml, parallel, dirs, samples):
             samples = heterogeneity.run(samples, run_parallel)
         with profile.report("population database", dirs):
             samples = population.prep_db_parallel(samples, run_parallel)
+        # after SV calling and SNV merging
+        with profile.report("create CNV PON", dirs):
+            samples = structural.create_cnv_pon(samples)
         with profile.report("peddy check", dirs):
             samples = peddy.run_peddy_parallel(samples, run_parallel)
         with profile.report("quality control", dirs):
@@ -277,10 +279,13 @@ def rnaseqpipeline(config, run_info_yaml, parallel, dirs, samples):
         with profile.report("bcbioRNAseq loading", dirs):
             tools_on = dd.get_in_samples(samples, dd.get_tools_on)
             bcbiornaseq_on = tools_on and "bcbiornaseq" in tools_on
-            if bcbiornaseq_on and len(samples) == 1:
-                logger.warn("bcbioRNASeq does not work with just one sample, skipping.")
-            else:
-                run_parallel("run_bcbiornaseqload", [sample])
+            if bcbiornaseq_on:
+                if len(samples) < 3:
+                    logger.warn("bcbioRNASeq needs at least three samples total, skipping.")
+                elif len(samples) > 100:
+                    logger.warn("Over 100 samples, skipping bcbioRNASeq.")
+                else:
+                    run_parallel("run_bcbiornaseqload", [sample])
     logger.info("Timing: finished")
     return samples
 
@@ -385,11 +390,16 @@ def chipseqpipeline(config, run_info_yaml, parallel, dirs, samples):
                     multiplier = peaks._get_multiplier(samples)) as run_parallel:
         with profile.report("peakcalling", dirs):
             samples = peaks.peakcall_prepare(samples, run_parallel)
+            samples = peaks.call_consensus(samples)
+            samples = run_parallel("run_chipseq_count", samples)
+
+    samples = peaks.create_peaktable(samples)
 
     with prun.start(_wres(parallel, ["picard", "fastqc"]),
                     samples, config, dirs, "qc") as run_parallel:
         with profile.report("quality control", dirs):
             samples = qcsummary.generate_parallel(samples, run_parallel)
+            samples = atac.create_ataqv_report(samples)
         with profile.report("upload", dirs):
             samples = run_parallel("upload_samples", samples)
             for sample in samples:
@@ -424,10 +434,15 @@ def wgbsseqpipeline(config, run_info_yaml, parallel, dirs, samples):
         with profile.report("cpg calling", dirs):
             samples = run_parallel("cpg_calling", samples)
 
-    # with prun.start(_wres(parallel, ["picard", "fastqc", "samtools"]),
-    #                 samples, config, dirs, "qc") as run_parallel:
-    #     with profile.report("quality control", dirs):
-    #         samples = qcsummary.generate_parallel(samples, run_parallel)
+    with prun.start(_wres(parallel, ["picard", "fastqc", "samtools"]),
+                     samples, config, dirs, "qc") as run_parallel:
+        with profile.report("quality control", dirs):
+            samples = qcsummary.generate_parallel(samples, run_parallel)
+        with profile.report("upload", dirs):
+            samples = run_parallel("upload_samples", samples)
+            for sample in samples:
+                run_parallel("upload_samples_project", [sample])
+    logger.info("Timing: finished")
     return samples
 
 
