@@ -12,6 +12,7 @@ import glob
 
 import toolz as tz
 
+from bcbio import bam
 from bcbio import utils
 from bcbio.cwl import cwlutils
 from bcbio.log import logger
@@ -63,6 +64,11 @@ def pipeline_summary(data):
     Handles standard and CWL (single QC output) cases.
     """
     data = utils.to_single_data(data)
+    if data["analysis"].startswith("wgbs-seq"):
+        bismark_bam = dd.get_align_bam(data)
+        sorted_bam = bam.sort(bismark_bam, data["config"])
+        data = dd.set_align_bam(data, sorted_bam)
+        data = dd.set_work_bam(data, bismark_bam)
     work_bam = dd.get_align_bam(data) or dd.get_work_bam(data)
     if not work_bam or not work_bam.endswith(".bam"):
         work_bam = None
@@ -100,7 +106,7 @@ def get_qc_tools(data):
     if analysis.startswith("chip-seq"):
         to_run.append("chipqc")
         if dd.get_chip_method(data) == "atac":
-            to_run.append("atac")
+            to_run.append("ataqv")
     if analysis.startswith("smallrna-seq"):
         to_run.append("small-rna")
         to_run.append("atropos")
@@ -113,7 +119,8 @@ def get_qc_tools(data):
         if vcfanno.is_human(data):
             to_run += ["contamination", "peddy"]
         if vcfutils.get_paired_phenotype(data):
-            to_run += ["viral"]
+            if "viral" not in dd.get_tools_off(data):
+                to_run += ["viral"]
         if damage.should_filter([data]):
             to_run += ["damage"]
     if dd.get_umi_consensus(data):
@@ -153,7 +160,7 @@ def _run_qc_tools(bam_file, data):
              "viral": viral.run,
              "preseq": preseq.run,
              "chipqc": chipseq.run,
-             "atac": atac.run
+             "ataqv": atac.run
              }
     qc_dir = utils.safe_makedir(os.path.join(data["dirs"]["work"], "qc", data["description"]))
     metrics = {}
