@@ -10,6 +10,7 @@ from bcbio.utils import filter_missing, flatten, to_single_data, file_exists, Rs
 from bcbio.distributed.transaction import file_transaction
 from bcbio.log import logger
 from bcbio.provenance import do
+from bcbio.pipeline import qcsummary
 
 def fast_rnaseq(samples, run_parallel):
     to_index = determine_indexes_to_make(samples)
@@ -97,14 +98,15 @@ def rnaseq_variant_calling(samples, run_parallel):
     """
     samples = run_parallel("run_rnaseq_variant_calling", samples)
     variantcaller = dd.get_variantcaller(to_single_data(samples[0]))
-    if variantcaller and ("gatk-haplotype" in variantcaller):
+    jointcaller = dd.get_jointcaller(to_single_data(samples[0]))
+    if jointcaller and 'gatk-haplotype-joint' in jointcaller:    
         out = []
         for d in joint.square_off(samples, run_parallel):
             out.extend([[to_single_data(xs)] for xs in multi.split_variants_by_sample(to_single_data(d))])
         samples = out
-    if variantcaller:
+    if variantcaller or jointcaller:
         samples = run_parallel("run_rnaseq_ann_filter", samples)
-    if variantcaller and ("gatk-haplotype" in variantcaller):
+    if jointcaller and 'gatk-haplotype-joint' in jointcaller:
         out = []
         for data in (to_single_data(xs) for xs in samples):
             if "variants" not in data:
@@ -147,9 +149,9 @@ def run_rnaseq_ann_filter(data):
             data = dd.set_vrn_file(data, eff_file)
         ann_file = population.run_vcfanno(dd.get_vrn_file(data), data)
         if ann_file:
-            data = dd.set_vrn_file(data, ann_file)
-    variantcaller = dd.get_variantcaller(data)
-    if variantcaller and ("gatk-haplotype" in variantcaller):
+            data = dd.set_vrn_file(data, ann_file)    
+    jointcaller = dd.get_jointcaller(data)
+    if jointcaller and 'gatk-haplotype-joint' in jointcaller:  
         filter_file = variation.gatk_filter_rnaseq(dd.get_vrn_file(data), data)
         data = dd.set_vrn_file(data, filter_file)
     # remove variants close to splice junctions
@@ -339,9 +341,9 @@ def combine_express(samples, combined):
                   dd.sample_data_iterator(samples) if dd.get_express_counts(x)]
     gtf_file = dd.get_gtf_file(samples[0][0])
     isoform_to_gene_file = os.path.join(os.path.dirname(combined), "isoform_to_gene.txt")
-    isoform_to_gene_file = express.isoform_to_gene_name(
-        gtf_file, isoform_to_gene_file, next(dd.sample_data_iterator(samples)))
     if len(to_combine) > 0:
+        isoform_to_gene_file = express.isoform_to_gene_name(
+            gtf_file, isoform_to_gene_file, next(dd.sample_data_iterator(samples)))
         eff_counts_combined_file = os.path.splitext(combined)[0] + ".isoform.express_counts"
         eff_counts_combined = count.combine_count_files(to_combine, eff_counts_combined_file, ext=".counts")
         to_combine = [dd.get_express_tpm(x) for x in
@@ -468,8 +470,8 @@ def combine_files(samples):
     else:
         fpkm_isoform_combined = None
     # combine DEXseq files
-    to_combine_dexseq = filter_missing([dd.get_dexseq_counts(data[0]) for data
-                                        in samples])
+    to_combine_dexseq = list(filter_missing([dd.get_dexseq_counts(data[0]) for data
+                                        in samples]))
     if to_combine_dexseq and combined:
         dexseq_combined_file = os.path.splitext(combined)[0] + ".dexseq"
         dexseq_combined = count.combine_count_files(to_combine_dexseq,
@@ -480,6 +482,17 @@ def combine_files(samples):
         dexseq_combined = None
     samples = spikein.combine_spikein(samples)
     tximport = load_tximport(data)
+    # don't fail runs while we get dependencies straightened out
+    try:
+        # we need metadata.csv to generate SE
+        work_dir = dd.get_work_dir(data)
+        metadata_file = os.path.join(work_dir, "metadata.csv")
+        if not file_exists(metadata_file):
+            qcsummary._merge_metadata(samples)
+        summarized_experiment = load_summarizedexperiment(data)
+        qc_report = generate_se_qc_report(data)
+    except Exception:
+        summarized_experiment = None
     updated_samples = []
     for data in dd.sample_data_iterator(samples):
         if combined:
@@ -500,6 +513,7 @@ def combine_files(samples):
         if gtf_file:
             data = dd.set_tx2gene(data, tx2gene_file)
         data = dd.set_tximport(data, tximport)
+        data = dd.set_summarized_experiment(data, summarized_experiment)
         updated_samples.append([data])
     return updated_samples
 
@@ -525,7 +539,7 @@ def determine_indexes_to_make(samples):
     return tomake
 
 def load_tximport(data):
-    rcmd = Rscript_cmd()
+    rcmd = Rscript_cmd("r36")
     salmon_dir = os.path.join(dd.get_work_dir(data), "salmon")
     tx2gene_file = os.path.join(dd.get_work_dir(data), "inputs", "transcriptome", "tx2gene.csv")
     out_dir = os.path.join(salmon_dir, "combined")
@@ -540,12 +554,49 @@ def load_tximport(data):
             f'library(tidyverse);'
             f'salmon_files = list.files("{salmon_dir}", pattern="quant.sf", recursive=TRUE, full.names=TRUE);'
             f'tx2gene = readr::read_csv("{tx2gene_file}", col_names=c("transcript", "gene")); '
-            f'samples = basename(dirname(dirname(salmon_files)));'
+            f'samples = basename(dirname(salmon_files));'
             f'names(salmon_files) = samples;'
-            f'txi = tximport::tximport(salmon_files, type="salmon", tx2gene=tx2gene, countsFromAbundance="lengthScaledTPM");'
-            f'readr::write_csv(txi$counts %>% as.data.frame() %>% tibble::rownames_to_column("gene"), "{tx_counts_file}");'
+            f'txi = tximport::tximport(salmon_files, type="salmon", tx2gene=tx2gene, countsFromAbundance="lengthScaledTPM", dropInfReps=TRUE);'
+            f'readr::write_csv(round(txi$counts) %>% as.data.frame() %>% tibble::rownames_to_column("gene"), "{tx_counts_file}");'
             f'readr::write_csv(txi$abundance %>% as.data.frame() %>% tibble::rownames_to_column("gene"), "{tx_tpm_file}");'
         )
         do.run([rcmd, "--vanilla", "-e", render_string], f"Loading tximport.")
     return {"gene_tpm": tpm_file,
             "gene_counts": counts_file}
+
+def load_summarizedexperiment(data):
+    """ create summarizedexperiment rds object
+    fails with n_samples = 1 """
+    # using r36 (4.0) - will eventually drop R3.5
+    rcmd = Rscript_cmd("r36")
+    se_script = os.path.join(os.path.dirname(__file__), os.pardir, "scripts",
+                             "R", "bcbio2se.R")
+    work_dir = dd.get_work_dir(data)
+    out_dir = os.path.join(work_dir, "salmon")
+    out_file = os.path.join(out_dir, "bcbio-se.rds")
+    if file_exists(out_file):
+        return out_file
+    with file_transaction(out_file) as tx_out_file:
+        cmd = f"{rcmd} --vanilla {se_script} {work_dir} {tx_out_file}"
+        message = f"Loading SummarizedExperiment."
+        do.run(cmd, message)
+    return out_file
+
+def generate_se_qc_report(data):
+    """ generate QC report based on SE RDS object"""
+    rcmd = Rscript_cmd("r36")
+    qc_script = os.path.join(os.path.dirname(__file__), os.pardir, "scripts",
+                             "R", "se2qc.Rmd")
+    work_dir = dd.get_work_dir(data)
+    out_file = os.path.join(work_dir, "qc", "bcbio-se.html")
+    rds_file = os.path.join(work_dir, "salmon", "bcbio-se.rds")
+    if file_exists(out_file):
+        return out_file
+    with file_transaction(out_file) as tx_out_file:
+        cmd = (
+            f"""{rcmd} --vanilla """
+            f"""-e 'rmarkdown::render("{qc_script}", params = list(rds_file="{rds_file}"), output_file="{tx_out_file}")'"""
+        )
+        message = f"Creating SE QC report"
+        do.run(cmd, message)
+    return out_file
