@@ -241,7 +241,7 @@ def _fill_validation_targets(data):
     sv_truth = tz.get_in(["config", "algorithm", "svvalidate"], data, {})
     sv_targets = (zip(itertools.repeat("svvalidate"), sv_truth.keys()) if isinstance(sv_truth, dict)
                   else [["svvalidate"]])
-    for vtarget in [list(xs) for xs in [["validate"], ["validate_regions"], ["variant_regions"]] + list(sv_targets)]:
+    for vtarget in [list(xs) for xs in [["validate"], ["validate_regions"]] + list(sv_targets)]:
         val = tz.get_in(["config", "algorithm"] + vtarget, data)
         if val and not os.path.exists(val) and not objectstore.is_remote(val):
             installed_val = os.path.normpath(os.path.join(os.path.dirname(ref_file), os.pardir, "validation", val))
@@ -477,6 +477,8 @@ def _check_for_problem_somatic_batches(items, config):
 
     We do not support multiple tumors in a single batch and VarDict(Java) does not
     handle pooled calling, only tumor/normal.
+
+    We allow multiple normals when batch: pon_build is set
     """
     to_check = []
     for data in items:
@@ -490,7 +492,9 @@ def _check_for_problem_somatic_batches(items, config):
             for batch in batches:
                 data_by_batches[batch].append(data)
     for batch, items in data_by_batches.items():
-        if vcfutils.get_paired(items):
+        if batch == "pon_build": 
+            pass
+        elif vcfutils.get_paired(items):
             vcfutils.check_paired_problems(items)
         elif len(items) > 1:
             vcs = vcfutils.get_somatic_variantcallers(items)
@@ -705,7 +709,7 @@ def _check_svcaller(item):
     if len(problem) > 0:
         raise ValueError("Unexpected algorithm 'svcaller' parameters: %s\n"
                          "Supported options: %s\n" % (" ".join(["'%s'" % x for x in problem]),
-                                                      sorted(list(allowed))))
+                                                      list(allowed)))
     if "gatk-cnv" in svs and "cnvkit" in svs:
         raise ValueError("%s uses `gatk-cnv' and 'cnvkit', please use on one of these CNV callers" %
                          dd.get_sample_name(item))
@@ -720,10 +724,11 @@ def _get_as_list(item, k):
 
 def _check_hetcaller(item):
     """Ensure upstream SV callers requires to heterogeneity analysis are available.
+    purecn has its own segmentation - no need in cnvkit or gatk-cnv
     """
     svs = _get_as_list(item, "svcaller")
     hets = _get_as_list(item, "hetcaller")
-    if hets or any([x in svs for x in ["titancna", "purecn"]]):
+    if hets or any([x in svs for x in ["titancna"]]):
         if not any([x in svs for x in ["cnvkit", "gatk-cnv"]]):
             raise ValueError("Heterogeneity caller used but need CNV calls. Add `gatk-cnv` "
                              "or `cnvkit` to `svcaller` in sample: %s" % item["description"])
