@@ -170,7 +170,7 @@ def _titan_cn_file(cnr_file, work_dir, data):
     cols = support_cols[cnvkit.bin_approach(data)]
     if not utils.file_uptodate(out_file, cnr_file):
         with file_transaction(data, out_file) as tx_out_file:
-            iterator = pd.read_table(cnr_file, sep="\t", iterator=True, header=0, comment="@")
+            iterator = pd.read_csv(cnr_file, sep="\t", iterator=True, header=0, comment="@")
             with open(tx_out_file, "w") as handle:
                 for chunk in iterator:
                     chunk = chunk[cols]
