@@ -70,6 +70,8 @@ def _get_files(sample):
         return _get_files_chipseq(sample)
     elif analysis.lower() in ["scrna-seq"]:
         return _get_files_scrnaseq(sample)
+    elif analysis.lower() in ["wgbs-seq"]:
+        return _get_files_wgbsseq(sample)
     else:
         return []
 
@@ -123,6 +125,29 @@ def _get_files_chipseq(sample):
     out = _maybe_add_greylist(algorithm, sample, out)
     return _add_meta(out, sample)
 
+def _get_files_wgbsseq(sample):
+    out = []
+    algorithm = sample["config"]["algorithm"]
+    out = _maybe_add_alignment(algorithm, sample, out)
+    bismark_report_dir = sample.get("bismark_report")
+    if bismark_report_dir:
+        out.append({"path": bismark_report_dir,
+                    "type": "directory",
+                    "ext": "bismark"})
+    bam_report = sample.get("bam_report")
+    if bam_report:
+        out.append({"path": bam_report,
+                    "type": "txt",
+                    "ext": "bam_report"})
+
+    deduplication_report = sample.get("deduplication_report")
+    if deduplication_report:
+        out.append({"path": deduplication_report,
+                    "type": "txt",
+                    "ext": "deduplication_report"})
+
+    return _add_meta(out, sample)
+
 def _add_meta(xs, sample=None, config=None):
     """Add top level information about the sample or flowcell to output.
 
@@ -146,9 +171,9 @@ def _add_meta(xs, sample=None, config=None):
         out.append(x)
     return out
 
+
 def _get_files_variantcall(sample):
-    """Return output files for the variant calling pipeline.
-    """
+    """Return output files for the variant calling pipeline"""
     out = []
     algorithm = sample["config"]["algorithm"]
     out = _maybe_add_summary(algorithm, sample, out)
@@ -156,13 +181,24 @@ def _get_files_variantcall(sample):
     out = _maybe_add_callable(sample, out)
     out = _maybe_add_disambiguate(algorithm, sample, out)
     out = _maybe_add_variant_file(algorithm, sample, out)
-    out = _maybe_add_sv(algorithm, sample, out)
+    out = _maybe_add_sv(sample, out)
     out = _maybe_add_hla(algorithm, sample, out)
     out = _maybe_add_heterogeneity(algorithm, sample, out)
 
     out = _maybe_add_validate(algorithm, sample, out)
+    out = _maybe_add_purecn_files(sample, out)
     return _add_meta(out, sample)
 
+def _maybe_add_purecn_files(sample, out):
+    """keep all files from purecn dir"""
+    purecn_coverage = tz.get_in(["depth", "bins", "purecn"], sample)
+    if purecn_coverage:
+        purecn_dir, purecn_file = os.path.split(purecn_coverage)
+        out.append({"path": purecn_dir,
+                    "type": "directory",
+                    "ext": "purecn"})
+    return out
+
 def _maybe_add_validate(algorith, sample, out):
     for i, plot in enumerate(tz.get_in(("validate", "grading_plots"), sample, [])):
         ptype = os.path.splitext(plot)[-1].replace(".", "")
@@ -246,13 +282,18 @@ def _get_batch_name(sample):
         batch = dd.get_sample_name(sample)
     return batch
 
-def _maybe_add_sv(algorithm, sample, out):
+
+def _maybe_add_sv(sample, out):
     if sample.get("align_bam") is not None and sample.get("sv"):
         batch = _get_batch_name(sample)
         for svcall in sample["sv"]:
             if svcall.get("variantcaller") == "seq2c":
                 out.extend(_get_variant_file(svcall, ("calls",), sample=batch))
                 out.extend(_get_variant_file(svcall, ("gender_predicted",), sample=batch))
+            elif svcall.get('variantcaller') == 'scramble':
+                out.extend(_get_variant_file(svcall, ('clusters_file',), suffix='-clusters',
+                                             sample=batch))
+                out.extend(_get_variant_file(svcall, ('mei_file',), suffix='-mei', sample=batch))
             for key in ["vrn_file", "cnr", "cns", "seg", "gainloss",
                         "segmetrics", "vrn_bed", "vrn_bedpe"]:
                 out.extend(_get_variant_file(svcall, (key,), sample=batch))
@@ -317,6 +358,7 @@ def _maybe_add_sv(algorithm, sample, out):
                                     "ext": "sv-validate%s" % ext})
     return out
 
+
 def _sample_variant_file_in_population(x):
     """Check if a sample file is the same as the population file.
 
@@ -669,7 +711,7 @@ def _maybe_add_trna(algorithm, sample, out):
 
 def _maybe_add_peaks(algorithm, sample, out):
     out_dir = sample.get("peaks_files", {})
-    if "NF" in out_dir.keys():
+    if dd.get_chip_method(sample) == "atac":
         for files in out_dir.values():
             for caller in files:
                 if caller == "main":
@@ -760,6 +802,10 @@ def _get_files_project(sample, upload_config):
     if multiqc:
         out.extend(_flatten_file_with_secondary(multiqc, "multiqc"))
 
+    ataqv = tz.get_in(["ataqv_report"], sample)
+    if ataqv:
+        out.extend(_flatten_file_with_secondary(ataqv, "ataqv"))
+
     if sample.get("seqcluster", {}):
         out.append({"path": sample["seqcluster"].get("out_dir"),
                     "type": "directory", "ext": "seqcluster"})
@@ -792,7 +838,8 @@ def _get_files_project(sample, upload_config):
         if x.get("validate") and x["validate"].get("grading_summary"):
             out.append({"path": x["validate"]["grading_summary"]})
             break
-    sv_project = set([])
+    sv_project = set()
+    pon_project = set()
     for svcall in sample.get("sv", []):
         if svcall.get("variantcaller") == "seq2c":
             if svcall.get("calls_all") and svcall["calls_all"] not in sv_project:
@@ -800,6 +847,24 @@ def _get_files_project(sample, upload_config):
                 out.append({"path": svcall["read_mapping"], "batch": "seq2c", "ext": "read_mapping", "type": "txt"})
                 out.append({"path": svcall["calls_all"], "batch": "seq2c", "ext": "calls", "type": "tsv"})
                 sv_project.add(svcall["calls_all"])
+        if svcall.get("variantcaller") == "gatkcnv":
+            if svcall.get("pon") and svcall["pon"] not in pon_project:
+                out.append({"path": svcall["pon"], "batch": "gatkcnv", "ext": "pon", "type": "hdf5"})
+                pon_project.add(svcall.get("pon"))
+
+    purecn_pon = tz.get_in(["config", "algorithm", "purecn_pon_build"], sample)
+    genome_build = dd.get_genome_build(sample)
+    if purecn_pon:
+        work_dir = tz.get_in(["dirs", "work"], sample)
+        gemini_dir = os.path.join(work_dir, "gemini")
+        mapping_bias_filename = f"mapping_bias_{genome_build}.rds"
+        mapping_bias_file = os.path.join(gemini_dir, mapping_bias_filename)
+        normal_db_file = f"normalDB_{genome_build}.rds"
+        normal_db = os.path.join(gemini_dir, normal_db_file)
+        if mapping_bias_file and normal_db:
+            out.append({"path": mapping_bias_file})
+            out.append({"path": normal_db})
+
     if "coverage" in sample:
         cov_db = tz.get_in(["coverage", "summary"], sample)
         if cov_db:
@@ -843,12 +908,14 @@ def _get_files_project(sample, upload_config):
                 out.append({"path": rda,
                             "type": "rda"})
         else:
-            out.append({"path": dd.get_combined_counts(sample)})
+            out.append({"path": dd.get_combined_counts(sample), "dir": "featureCounts"})
+    if dd.get_summarized_experiment(sample):
+        out.append({"path": dd.get_summarized_experiment(sample), "dir": "counts"})
     if dd.get_tximport(sample):
         out.append({"path": dd.get_tximport(sample)["gene_tpm"], "dir": "tpm"})
         out.append({"path": dd.get_tximport(sample)["gene_counts"], "dir": "counts"})
     if dd.get_annotated_combined_counts(sample):
-        out.append({"path": dd.get_annotated_combined_counts(sample)})
+        out.append({"path": dd.get_annotated_combined_counts(sample), "dir": "featureCounts"})
     if dd.get_combined_fpkm(sample):
         out.append({"path": dd.get_combined_fpkm(sample)})
     if dd.get_combined_fpkm_isoform(sample):
@@ -876,9 +943,19 @@ def _get_files_project(sample, upload_config):
         out.append({"path": dd.get_tx2gene(sample)})
     if dd.get_spikein_counts(sample):
         out.append({"path": dd.get_spikein_counts(sample)})
+    if tz.get_in(("peaks_files", "consensus", "main"), sample):
+        out.append({"path": tz.get_in(("peaks_files", "consensus", "main"), sample), "dir": "consensus"})
+    if tz.get_in(("peak_counts", "peaktable"), sample):
+        out.append({"path": tz.get_in(("peak_counts", "peaktable"), sample), "dir": "consensus"})
+
     transcriptome_dir = os.path.join(dd.get_work_dir(sample), "inputs",
                                      "transcriptome")
     if os.path.exists(transcriptome_dir):
         out.append({"path": transcriptome_dir, "type": "directory",
                     "ext": "transcriptome"})
+
+    rnaseq_se_qc_file = os.path.join(dd.get_work_dir(sample), "qc", "bcbio-se.html")
+    if os.path.exists(rnaseq_se_qc_file):
+        out.append({"path": rnaseq_se_qc_file})
+
     return _add_meta(out, config=upload_config)
