@@ -99,7 +99,7 @@ def _pick_lead_item(items):
     if paired:
         return paired.tumor_data
     else:
-        return items[0]
+        return list(items)[0]
 
 def _normalize_cwl_inputs(items):
     """Extract variation and validation data from CWL input list of batched samples.
@@ -578,7 +578,7 @@ def summarize_grading(samples, vkey="validate"):
             writer.writerow(header)
             plot_data = []
             plot_files = []
-            for data in sorted(vitems, key=lambda x: x.get("lane", dd.get_sample_name(x))):
+            for data in sorted(vitems, key=lambda x: x.get("lane", dd.get_sample_name(x)) or ""):
                 validations = [variant.get(vkey) for variant in data.get("variants", [])
                                if isinstance(variant, dict)]
                 validations = [v for v in validations if v]
@@ -672,7 +672,7 @@ def _get_validate_plotdata_yaml(grading_file, data):
     """Retrieve validation plot data from grading YAML file (old style).
     """
     with open(grading_file) as in_handle:
-        grade_stats = yaml.load(in_handle)
+        grade_stats = yaml.safe_load(in_handle)
     for sample_stats in grade_stats:
         sample = sample_stats["sample"]
         for vtype, cat, val in _flatten_grading(sample_stats):
